==> social_auth_keycloak-1.0.x-dev.tar.gz: social_auth_keycloak/src/KeycloakAuthManager.php <==
<?php

declare(strict_types=1);

namespace Drupal\social_auth_keycloak;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\social_auth\AuthManager\OAuth2Manager;
use League\OAuth2\Client\Provider\Exception\IdentityProviderException;
use League\OAuth2\Client\Provider\ResourceOwnerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Contains all the logic for Keycloak OAuth2 authentication.
 */
final class KeycloakAuthManager extends OAuth2Manager {

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   Used for accessing configuration object factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   Used to get the authorization code from the callback request.
   */
  public function __construct(ConfigFactory $configFactory,
                              LoggerChannelFactoryInterface $logger_factory,
                              RequestStack $request_stack) {

    parent::__construct($configFactory->get('social_auth_keycloak.settings'),
                        $logger_factory,
                        $this->request = $request_stack->getCurrentRequest());
  }

  /**
   * {@inheritdoc}
   */
  public function authenticate(): void {
    try {
      $this->setAccessToken($this->client->getAccessToken('authorization_code',
        ['code' => $this->request->query->get('code')]));
    }
    catch (IdentityProviderException $e) {
      $this->loggerFactory->get('social_auth_keycloak')
        ->error('There was an error during authentication. Exception: ' . $e->getMessage());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getUserInfo(): ResourceOwnerInterface {
    if ($this->user === NULL) {
      $this->user = $this->client->getResourceOwner($this->getAccessToken());
    }

    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function getAuthorizationUrl(): string {
    $scopes = [
      'email',
      'profile',
    ];

    $extra_scopes = $this->getScopes();
    if ($extra_scopes) {
      $scopes = \array_merge($scopes, \explode(',', $extra_scopes));
    }

    // Returns the URL where user will be redirected.
    return $this->client->getAuthorizationUrl([
      'scope' => $scopes,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getEndPoints() {
    $server_url = $this->settings->get('server_url');
    $realm = $this->settings->get('realm');
    return "$server_url|$realm";
  }

  /**
   * {@inheritdoc}
   */
  public function requestEndPoint($method, $path, $domain = NULL, array $options = []): ?array {
    $realm = $this->settings->get('realm');
    $url = sprintf('%s/realms/%s/protocol/openid-connect/userinfo', $path, $realm);

    $request = $this->client->getAuthenticatedRequest($method, $url, $this->getAccessToken(), $options);

    try {
      return $this->client->getParsedResponse($request);
    }
    catch (IdentityProviderException|\UnexpectedValueException $e) {
      $this->loggerFactory->get('social_auth_keycloak')
        ->error('There was an error when requesting ' . $url . '. Exception: ' . $e->getMessage());
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getState(): string {
    return $this->client->getState();
  }

}

==> social_auth_keycloak-2.0.x-dev.tar.gz: social_auth_keycloak/src/KeycloakAuthManager.php <==
<?php

declare(strict_types=1);

namespace Drupal\social_auth_keycloak;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\social_auth\AuthManager\OAuth2Manager;
use Drupal\social_auth\User\SocialAuthUser;
use Drupal\social_auth\User\SocialAuthUserInterface;
use League\OAuth2\Client\Provider\Exception\IdentityProviderException;
use Stevenmaguire\OAuth2\Client\Provider\KeycloakResourceOwner;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Contains all the logic for Keycloak OAuth2 authentication.
 */
final class KeycloakAuthManager extends OAuth2Manager {

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   Used for accessing configuration object factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   Used to get the authorization code from the callback request.
   */
  public function __construct(ConfigFactory $configFactory,
                              LoggerChannelFactoryInterface $logger_factory,
                              RequestStack $request_stack) {

    parent::__construct($configFactory->get('social_auth_keycloak.settings'),
                        $logger_factory,
                        $this->request = $request_stack->getCurrentRequest());
  }

  /**
   * {@inheritdoc}
   */
  public function authenticate(): void {
    try {
      $this->setAccessToken($this->client->getAccessToken('authorization_code',
        ['code' => $this->request->query->get('code')]));
    }
    catch (IdentityProviderException $e) {
      $this->loggerFactory->get('social_auth_keycloak')
        ->error('There was an error during authentication. Exception: ' . $e->getMessage());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getUserInfo(): SocialAuthUserInterface {
    if ($this->user === NULL) {
      $owner = $this->client->getResourceOwner($this->getAccessToken());
      assert($owner instanceof KeycloakResourceOwner);
      $this->user = new SocialAuthUser(
        $owner->toArray()['preferred_username'] ?? $owner->getEmail(),
        $owner->getId(),
        $this->getAccessToken()->getToken(),
        $owner->getEmail(),
        $owner->toArray()['picture'] ?? NULL,
        $this->getExtraDetails()
      );
      if (array_key_exists('given_name', $owner->toArray())) {
        $this->user->setFirstName($owner->toArray()['given_name']);
      }
      if (array_key_exists('family_name', $owner->toArray())) {
        $this->user->setLastName($owner->toArray()['family_name']);
      }
      if (array_key_exists('zoneinfo', $owner->toArray())) {
        $this->user->addData('zoneinfo', $owner->toArray()['zoneinfo']);
      }
      if (array_key_exists('email_verified', $owner->toArray())) {
        $this->user->addData('email_verified', $owner->toArray()['email_verified']);
      }
    }

    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function getAuthorizationUrl(): string {
    $scopes = [
      'email',
      'profile',
    ];

    $extra_scopes = $this->getScopes();
    if ($extra_scopes) {
      $scopes = \array_merge($scopes, \explode(',', $extra_scopes));
    }

    // Returns the URL where user will be redirected.
    return $this->client->getAuthorizationUrl([
      'scope' => $scopes,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getEndPoints(): string {
    $server_url = $this->settings->get('server_url');
    $realm = $this->settings->get('realm');
    return "$server_url|$realm";
  }

  /**
   * {@inheritdoc}
   */
  public function requestEndPoint($method, $path, $domain = NULL, array $options = []): ?array {
    $realm = $this->settings->get('realm');
    $url = sprintf('%s/realms/%s/protocol/openid-connect/userinfo', $path, $realm);

    $request = $this->client->getAuthenticatedRequest($method, $url, $this->getAccessToken(), $options);

    try {
      return $this->client->getParsedResponse($request);
    }
    catch (IdentityProviderException|\UnexpectedValueException $e) {
      $this->loggerFactory->get('social_auth_keycloak')
        ->error('There was an error when requesting ' . $url . '. Exception: ' . $e->getMessage());
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getState(): string {
    return $this->client->getState();
  }

}
